aboutsummaryrefslogtreecommitdiff
path: root/src/include/taler_merchant_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_merchant_service.h')
-rw-r--r--src/include/taler_merchant_service.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/include/taler_merchant_service.h b/src/include/taler_merchant_service.h
index 68550be8..19f059b6 100644
--- a/src/include/taler_merchant_service.h
+++ b/src/include/taler_merchant_service.h
@@ -2385,14 +2385,14 @@ struct TALER_MERCHANT_PostReservesHandle;
* @param cls closure
* @param hr HTTP response details
* @param reserve_pub public key of the created reserve, NULL on error
* @param payto_url where to make the payment to for filling the reserve, NULL on error
*/
typedef void
(*TALER_MERCHANT_PostReservesCallback) (
void *cls,
const struct TALER_MERCHANT_HttpResponse *hr,
const struct TALER_ReservePublicKeyP *reserve_pub,
- const char *payto_url);
+ const char *payto_uri);
/**
@@ -2415,7 +2415,7 @@ TALER_MERCHANT_reserves_post (
const char *exchange_url,
const char *wire_method,
TALER_MERCHANT_PostReservesCallback cb,
- void *cls);
+ void *cb_cls);
/**
@@ -2385,14 +2385,14 @@ struct TALER_MERCHANT_PostReservesHandle;
* @param hr HTTP response details
* @param reserve_pub public key of the created reserve, NULL on error
- * @param payto_url where to make the payment to for filling the reserve, NULL on error
+ * @param payto_uri where to make the payment to for filling the reserve, NULL on error
*/
typedef void